'''OpenGL extension EXT.import_context

This module customises the behaviour of the 
OpenGL.raw.GLX.EXT.import_context to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension allows multiple X clients to share an indirect
	rendering context.
	
	Additional convenience procedures to get the current Display*
	bound to a context as well as other context information are
	also added.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/import_context.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLX import _types, _glgets
from OpenGL.raw.GLX.EXT.import_context import *
from OpenGL.raw.GLX.EXT.import_context import _EXTENSION_NAME

def glInitImportContextEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION